@@ -122,7 +122,7 @@ def _create_table(connection, table, valid_names, dtypes):
     connection.execute(request)
 
 
-sqlite3.register_adapter(np.int64, lambda val: int(val))
+sqlite3.register_adapter(np.int_, lambda val: int(val))
 
 
 def ndarray2sql(database, table, data, if_exists='fail'):
